@@ -1,25 +1,50 @@
 #!/usr/bin/env python3
 
 import logging
+import os
+import platform
 import pyo
 import sys
-from shakersynth.config import config
+import time
+from importlib.resources import read_text
+from shakersynth.config.loader import create_default_config_file, load_config
 from shakersynth.aircraft.aircraft import Aircraft
 from shakersynth.receiver.shakersynth import ShakersynthReceiver
 
+config = load_config()
 logging.basicConfig()
 log = logging.getLogger("main")
-log.setLevel(config.log_level)
+log.setLevel(config.log.level)
+
+
+def install_lua():
+    if not platform.system() == 'Windows':
+        log.info('Skipping export script setup: not running on Windows.')
+        return
+
+    user_profile = os.path.expandvars('%UserProfile%')
+    for dcs in ['DCS', 'DCS.openbeta']:
+        script_dir = os.path.join(user_profile, 'Saved Games', dcs, 'Scripts')
+        script_file = os.path.join(script_dir, 'Shakersynth.lua')
+        if os.path.isdir(script_dir):
+            with open(script_file, 'w') as lua:
+                try:
+                    lua.write(read_text(__package__, 'Shakersynth.lua'))
+                except Exception:
+                    log.error(f"Failed to write export script: {script_file}")
 
 
 def main():
     print("\n" + "-" * 35 + "Shakersynth" + "-" * 35)
+    create_default_config_file()
+    install_lua()
+
     # Audio synthesis setup.
     server = pyo.Server(
         nchnls=2,
         duplex=0,
-        buffersize=config.buffer_size,
-        sr=config.sample_rate
+        buffersize=config.audio.buffer_size,
+        sr=config.audio.sample_rate
     )
     server.setVerbosity(1)
 
@@ -45,15 +70,11 @@ def main():
 
     server.boot()
     server.start()
-    server.setAmp(config.global_volume)
+    server.setAmp(config.audio.global_volume)
 
     # Receive Telemetry from the Shakersynth DCS export script.
     receiver = ShakersynthReceiver()
 
-    # All telemetry processing and sound synthesis happens in the aircraft
-    # model.
-    aircraft = Aircraft()
-
     print("*" * 80)
     print("ShakerSynth now running.")
     print("Press ctrl+c to exit.")
@@ -61,15 +82,18 @@ def main():
     log.info("Waiting for initial telemetry.")
 
     # A little state machine to keep track of our aircraft and telemetry.
+    running = False
     while True:
         telemetry = receiver.receive()
-        running = aircraft.is_running
 
         if telemetry and not running:
             # Then we have just started a mission.
-            log.info("Starting new aircraft: %s" % telemetry["module"])
-            aircraft.update(telemetry)
+            module = telemetry['module']
+            log.info(f"Starting new aircraft: {module}")
+            aircraft = Aircraft(module)
             aircraft.start()
+            aircraft.update(telemetry)
+            running = aircraft.is_running
 
         elif telemetry and running:
             # Then things are ticking along nicely.
@@ -78,8 +102,11 @@ def main():
         elif running and not telemetry:
             # Then we got an empty telemetry object while running an aircraft.
             # This signifies that we left the mission or lost contact with DCS.
-            log.info("Shutting down aircraft.")
+            log.info(f"Shutting down aircraft: {aircraft.module}")
             aircraft.stop()
+            running = aircraft.is_running
+            time.sleep(0.1)
+            del(aircraft)
 
 
 if __name__ == "__main__":
