@@ -2,10 +2,11 @@ import logging
 import socket
 import yaml
 from func_timeout import func_set_timeout, FunctionTimedOut  # type: ignore
-from shakersynth.config import config
+from shakersynth.config import loader
 
+config = loader.load_config()
 log = logging.getLogger(__name__)
-log.setLevel(config.log_level)
+log.setLevel(config.log.level)
 
 
 class ShakersynthReceiver():
